@@ -11,6 +11,9 @@ from .items import (
     Video,
     ROI,
     Image,
+    Dataset,
+    Timepoint,
+    Era,
 )
 
 
@@ -25,6 +28,10 @@ __all__ = [
     "OmeroFile",
     "Metric",
     "Video",
+    "Dataset",
     "Image",
     "ROI",
+    "Dataset",
+    "Era",
+    "Timepoint",
 ]
