@@ -47,7 +47,7 @@ from mikro.scalars import XArrayInput, ParquetInput, BigFile
 from aiobotocore.session import get_session
 import ntpath
 import logging
-
+import zarr
 
 logger = logging.getLogger(__name__)
 current_datalayer = contextvars.ContextVar("current_datalayer", default=None)
@@ -83,6 +83,10 @@ class DataLayer(KoiledModel):
     _s3fs: Optional[s3fs.S3FileSystem] = None
     _connected = False
     auto_connect = True
+    cache: int = 2**30
+    """ O means no cache, 2**30 means 1GB cache"""
+    strict: bool = False
+    """ If True, it will not try to recover potential errors form the boto core client (only accept PermissionError). This is due to bad error handling on the boto core client when accesskeys are expired. """
 
     def _storedataset(self, dataset: xr.Dataset, path):
         store = self.fs.get_mapper(path)
@@ -189,10 +193,24 @@ class DataLayer(KoiledModel):
             else:
                 logger.error("Permission error, could not get new credentials")
                 raise e
+        except Exception as e:
+            if self.strict:
+                raise e
+            else:
+                logger.error("Permission error, trying to get new credentials")
+                if retry < self.max_retries:
+                    self.reconnect()
+                    return self.test_path_accessible(path, retry=retry + 1)
+                else:
+                    logger.error("Permission error, could not get new credentials")
+                    raise e
 
     def open_store(self, path):
         if self.test_path_accessible(path):
-            return self.fs.get_mapper(path)
+            if self.cache > 0:
+                return zarr.LRUStoreCache(self.fs.get_mapper(path), self.cache)
+            else:
+                return self.fs.get_mapper(path)
 
     @property
     def fs(self):
