@@ -8,6 +8,9 @@ from mikro.api import OmeroFileFragment as OmeroFile
 from mikro.api import MetricFragment as Metric
 from mikro.api import VideoFragment as Video
 from mikro.api import ROIFragment as ROI
+from mikro.api import DatasetFragment as Dataset
+from mikro.api import EraFragment as Era
+from mikro.api import TimepointFragment as Timepoint
 
 
 __all__ = [
@@ -20,5 +23,8 @@ __all__ = [
     "OmeroFile",
     "Metric",
     "Video",
+    "Dataset",
     "ROI",
+    "Era",
+    "Timepoint",
 ]
