@@ -47,7 +47,9 @@ if rekuest:
         identifier="@mikro/channel",
         expand=aget_channel,
         scope=Scope.GLOBAL,
-        default_widget=None,
+        default_widget=SearchWidget(
+            query=SearchChannelsQuery.Meta.document, ward="mikro"
+        ),
     )
     structure_reg.register_as_structure(
         DimensionMapFragment,
@@ -65,6 +67,15 @@ if rekuest:
             query=Search_sampleQuery.Meta.document, ward="mikro"
         ),
     )
+    structure_reg.register_as_structure(
+        GraphFragment,
+        identifier="@mikro/graph",
+        expand=aget_graph,
+        scope=Scope.GLOBAL,
+        default_widget=SearchWidget(
+            query=Search_graphsQuery.Meta.document, ward="mikro"
+        ),
+    )
     structure_reg.register_as_structure(
         TableFragment,
         identifier="@mikro/table",
@@ -153,6 +164,22 @@ if rekuest:
             query=Search_stagesQuery.Meta.document, ward="mikro"
         ),
     )
+    structure_reg.register_as_structure(
+        EraFragment,
+        identifier="@mikro/era",
+        scope=Scope.GLOBAL,
+        expand=aget_era,
+        default_widget=SearchWidget(query=SearchErasQuery.Meta.document, ward="mikro"),
+    )
+    structure_reg.register_as_structure(
+        TimepointFragment,
+        identifier="@mikro/timepoint",
+        scope=Scope.GLOBAL,
+        expand=aget_timepoint,
+        default_widget=SearchWidget(
+            query=SearchTimepointsQuery.Meta.document, ward="mikro"
+        ),
+    )
     structure_reg.register_as_structure(
         DatasetFragment,
         identifier="@mikro/dataset",
@@ -171,6 +198,15 @@ if rekuest:
             query=Search_objectivesQuery.Meta.document, ward="mikro"
         ),
     )
+    structure_reg.register_as_structure(
+        CameraFragment,
+        identifier="@mikro/camera",
+        scope=Scope.GLOBAL,
+        expand=aexpand_camera,
+        default_widget=SearchWidget(
+            query=Search_camerasQuery.Meta.document, ward="mikro"
+        ),
+    )
     structure_reg.register_as_structure(
         ModelFragment,
         identifier="@mikro/model",
